DyDataGroup<G> class

Constructors

DyDataGroup({required int start, required int end, required String groupId, required G? groupData})

Properties

end int
index item when on start of group list
getter/setter pair
groupData ↔ G?
data in Group list
getter/setter pair
groupId String
identifier key for group list data
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
index item when on start of group list
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateGroupData<T, G>(List<DyItemData<T>> list, {required Map<String, G> checkKeyIdentifier(DyItemDataInfo<T>)}) List<DyDataGroup<G>>