SelectPagingListViewController<T> class

Inheritance

Constructors

SelectPagingListViewController({int pageStart = 0, ScrollController? scrollController, Axis direction = Axis.vertical, bool enabledPullLeftReload = false, required void refreshStateParentWidget(), required bool compareSelectedItem(T, T), List<PageableListViewItemDataGroup> generateGroupData(List<PageableListViewItemData<T>>)?})

Properties

compareSelectedItem bool Function(T, T)
getter/setter pair
direction Axis
List direction of this list, vertical or horizontal mode
getter/setter pair
enabledPullLeftReload bool
Configuration to enabled pull to refresh on left in direction horizontal mode
getter/setter pair
errorText String?
Error message
getter/setter pair
generateGroupData List<PageableListViewItemDataGroup> Function(List<PageableListViewItemData<T>>)?
Function to generate list Group Data
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasNextPage bool
Indicator if list has more item to load on next page
getter/setter pair
isLoading bool
Indicator flag in loading on process fetch data of first page
getter/setter pair
isLoadingNextPage bool
Indicator flag in loading on process fetch data of next page
getter/setter pair
item List<PageableListViewItemData<T>>
List item data
getter/setter pair
page int
Current last page of the list
getter/setter pair
pageStart int
Index page to start
getter/setter pair
refreshIndicatorKey GlobalKey<RefreshIndicatorState>?
getter/setter pair
refreshStateParentWidget ↔ void Function()
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scroll ScrollController
ScrollController for this list
getter/setter pair
seletedItem List<T>
List item of selected
getter/setter pair

Methods

addItemList(List<T> list) → void
Function to data to list manually
addItemListForLastPage(List<T> list) → void
Function to data of last page to list manually
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearSelectedItem() → void
Function to clear all selected item
dispose() → void
Discards any resources used by the object.
override
fetchFirstPage({required Future<List<T>> fetchApi(), bool isLastPage = false, bool triggerLoadingState = true}) Future<void>
This function is for fetch data for first page
fetchNextPage({required Future<List<T>> fetchApi()}) Future<void>
Function to fetch next page data
fetchWithoutPaging({required Future<List<T>> fetchApi(), bool triggerLoadingState = true}) Future<void>
This function is for fetch data without paging feature
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
Function to reset page state to initial state
selectAllItem() → void
Function to select all item on list
selectItem({required PageableListViewItemData<T> data, required bool isSetToSelected}) → void
Function to select or unselect item
setCurrentPageAsLastPage() → void
Function to manually set current page as last page
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited