buildertopWidget property

List<Widget> Function(BuildContext)? buildertopWidget
final

Custom Builder Widget UI to be show before widget list item

On mode Vertical, this widget will be show on top of list On mode Horizontal, this widget will be show on left of list

Implementation

final List<Widget> Function(BuildContext)? buildertopWidget;