loadingNextPageBuilder property

Widget Function(BuildContext, int)? loadingNextPageBuilder
final

Custom Widget UI to be show when in loading for fetch data of next page

On mode Vertical, this widget will be show on bottom of list On mode Horizontal, this widget will be show on right of list

Implementation

final Widget Function(BuildContext, int)? loadingNextPageBuilder;